@@ -38,6 +38,7 @@ function(fit, xl, xu, d = "best", w = 1, lwd, xlab, ylab,
   
 	weight <- matrix(w/sum(w), nxTotal, n.experts, byrow = T)
  
+	
 	for(i in 1:n.experts){
 		densitydata <- expertdensity(fit, d[i], ex = i, xl, xu, ql, qu, nx)
 		x[, i] <- densitydata$x
@@ -58,7 +59,9 @@ function(fit, xl, xu, d = "best", w = 1, lwd, xlab, ylab,
 	                                 levels = c("individual",
 	                                            lpname))
 	)
-	
+	df1$expert <- factor(df1$expert, 
+	                     levels = c(expertnames, lpname))
+
 	if(legend_full){
 	  
 	  cols <- scales::hue_pal()(n.experts + 1)
@@ -71,9 +74,13 @@ function(fit, xl, xu, d = "best", w = 1, lwd, xlab, ylab,
 	                        colour = expert, 
 	                        linetype = expert, 
 	                        size = expert)) +
-	    scale_colour_manual(values = cols) +
-	    scale_linetype_manual(values = linetypes) +
-	    scale_size_manual(values = sizes)}else{
+	    scale_colour_manual(values = cols,
+	                        breaks = c(expertnames, lpname )) +
+	    scale_linetype_manual(values = linetypes,
+	                          breaks = c(expertnames, lpname )) +
+	    scale_size_manual(values = sizes,
+	                      breaks = c(expertnames, lpname ))}else{
+	                       
 	      p1 <- ggplot(df1, aes(x = x, y = fx, 
 	                            colour =  ftype, 
 	                            linetype=ftype, size =ftype)) +
@@ -81,7 +88,9 @@ function(fit, xl, xu, d = "best", w = 1, lwd, xlab, ylab,
 	        scale_size_manual(name = "distribution", values = lwd * c(.5, 1.5)) +
 	        scale_color_manual(name = "distribution", values = c("black", "red"))
 	    }
-	
+
+	if(legend_full){
+		
 	for(i in 1:n.experts){
 	  if(d[i] == "hist"){
 	    p1 <- p1 + geom_step(data = subset(df1, expert == expertnames[i]),
@@ -89,7 +98,18 @@ function(fit, xl, xu, d = "best", w = 1, lwd, xlab, ylab,
 	  }else{
 	    p1 <- p1 + geom_line(data = subset(df1, expert == expertnames[i]),
 	                   aes(colour = expert))
-	  } 
+	  }
+	}
+	}else{
+	  for(i in 1:n.experts){
+	    if(d[i] == "hist"){
+	      p1 <- p1 + geom_step(data = subset(df1, expert == expertnames[i]),
+	                           aes(colour = ftype))
+	    }else{
+	      p1 <- p1 + geom_line(data = subset(df1, expert == expertnames[i]),
+	                           aes(colour = ftype))
+	    }
+	  }
 	}
 	
 	if(length(unique(d)) == 1 & d[1] == "hist"){
