@@ -9,14 +9,9 @@
 #' @param fit An object of class \code{elicitation}.
 #' @param d The distribution fitted to each expert's probabilities. Options are
 #' \code{"normal"}, \code{"t"}, \code{"gamma"}, \code{"lognormal"},
-#' \code{"logt"},\code{"beta"}, \code{"hist"} (for a histogram fit), and
+#' \code{"logt"},\code{"beta"}, \code{"mirrorgamma"},
+#' \code{"mirrorlognormal"}, \code{"mirrorlogt"} \code{"hist"} (for a histogram fit), and
 #' \code{"best"} (for best fitting)
-#' @param int Set \code{int = TRUE} to use interactive plotting (using the
-#' shiny package). If plotting for a single expert, the argument \code{d} is
-#' ignored, as distributions can be chosen within the display. If plotting for
-#' multiple experts, feedback quantiles are not displayed, and the argument
-#' \code{lp} is ignored, as the option to show a linear pool can be chosen
-#' within the display.
 #' @param xl The lower limit for the x-axis. The default is the 0.001 quantile
 #' of the fitted distribution (or the 0.001 quantile of a fitted normal
 #' distribution, if a histogram fit is chosen).
@@ -44,7 +39,8 @@
 #' @param legend_full If plotting a linear pool, set \code{ind = TRUE} for each expert
 #' to be plotted with a different colour, and \code{ind = FALSE} for each expert to be 
 #' plotted with the same colour, reducing the legend size.
-#' @param percentages Set to \code{TRUE} to use percentages on the x-axis. 
+#' @param percentages Set to \code{TRUE} to use percentages on the x-axis.
+#' @param returnPlot Set to \code{TRUE} to return the plot as a ggplot object.
 #' @author Jeremy Oakley <j.oakley@@sheffield.ac.uk>
 #' @examples
 #' 
@@ -64,25 +60,20 @@
 #' # Plot a fitted beta distribution for expert 2, and show 5th and 95th percentiles
 #' plotfit(myfit, d = "beta", ql = 0.05, qu = 0.95, ex = 2)
 #' 
-#' # Use interactive plotting for for expert 2, and show 5th and 95th percentiles
-#' plotfit(myfit, int = T, ex = 2)
 #' 
 #' # Plot a linear pool, giving double weight to expert 1
 #' plotfit(myfit,  lp = T, lpw = c(2,1))
 #' 
-#' # Use interactive plotting, giving double weight to expert 1, if a linear pool is displayed
-#' plotfit(myfit,  int = T, lpw = c(2,1))
 #' 
 #' # Plot a linear pool, giving double weight to expert 1, 
-#' # show 5th and 95th percentiles, supress plotting of individual distributions, 
+#' # show 5th and 95th percentiles, surpress plotting of individual distributions, 
 #' # and force use of Beta distributions
 #' plotfit(myfit, d = "beta",  lp = T, lpw = c(2,1), ql = 0.05, qu = 0.95, ind=FALSE )
 #' }
 #' @import graphics
 #' @export
 plotfit <- function(fit, 
-                    d = "best", 
-                    int = FALSE, 
+                    d = "best",
                     xl = -Inf, 
                     xu = Inf, 
                     ql = NA, 
@@ -97,7 +88,8 @@ plotfit <- function(fit,
                     xlab = "x",
                     ylab = expression(f[X](x)),
                     legend_full = TRUE,
-                    percentages = FALSE){
+                    percentages = FALSE,
+                    returnPlot = FALSE){
   
 
   if(d=="beta" & (min(fit$limits) == -Inf | max(fit$limits) == Inf )){stop("Parameter limits must be finite to fit a beta distribution")}
@@ -113,9 +105,12 @@ plotfit <- function(fit,
   if(nrow(fit$vals)>1 & is.na(ex)==T & lp==F){
     if(xl == -Inf & min(fit$limits[,1]) > -Inf){xl <- min(fit$limits[,1]) }
     if(xu == Inf & max(fit$limits[,2]) < Inf){xu <- max(fit$limits[,2]) }
-    if(int == FALSE){suppressWarnings(print(makeGroupPlot(fit, xl, xu, d, lwd, xlab, ylab)))}else{
-      shinyplotgroup(fit, xl, xu, lpw, lwd, xlab, ylab)
-    }
+      p1 <- suppressWarnings(makeGroupPlot(fit, xl, xu, d, lwd, xlab, ylab,
+                                           expertnames = rownames(fit$Normal)))
+      print(p1)
+      if(returnPlot){
+        return(p1)
+      }
   }
   
   if(nrow(fit$vals)>1 & lp==T){
@@ -131,9 +126,13 @@ plotfit <- function(fit,
       f2 <- feedback(fit, quantiles=0.99, dist=d)
       xu <- max(f2$expert.quantiles)
     }
-    if(int == FALSE){print(makeLinearPoolPlot(fit, xl, xu,  d , lpw,
-                                              lwd, xlab, ylab, legend_full))}else{
-      shinyplotgroup(fit, xl, xu, lpw, lwd, xlab, ylab, legend_full)
+    p1 <- makeLinearPoolPlot(fit, xl, xu,  d , lpw,
+                                              lwd, xlab, ylab, legend_full,
+                                              expertnames = rownames(fit$Normal)
+                                              )
+    print(p1)
+    if(returnPlot){
+      return(p1)
     }
     
   }
@@ -141,31 +140,37 @@ plotfit <- function(fit,
   if(nrow(fit$vals)>1 & is.na(ex)==F){
     if(xl == -Inf & fit$limits[ex,1] > -Inf){xl <- fit$limits[ex,1] }
     if(xu == Inf & fit$limits[ex,2] < Inf){xu <- fit$limits[ex,2] }
-    if(int == FALSE){suppressWarnings(print(makeSingleExpertPlot(fit, d, 
+    p1 <- suppressWarnings(makeSingleExpertPlot(fit, d, 
                                                                  xl, xu, 
                                                                  ql, qu, 
                                                                  sf, ex = ex, 
                                                                  lwd, xlab, 
                                                                  ylab,
                                                                  percentages)
-                                            )
+                                            
                                       )
-      }else{
-      shinyplotsingle(fit, xl, xu, ql, qu, ex, xlab, ylab, percentages)
+    print(p1)
+    if(returnPlot){
+      return(p1)
     }
+      
     
   }
   
  
   if(nrow(fit$vals)==1){
-    if(int == FALSE){
-      print(suppressWarnings(makeSingleExpertPlot(fit, d, xl, 
+    
+      p1 <- suppressWarnings(makeSingleExpertPlot(fit, d, xl, 
                                                   xu, ql, qu, sf, ex = 1,
                                                   lwd, xlab, ylab,
-                                                  percentages)))}else{
-      suppressWarnings(shinyplotsingle(fit, xl, xu, ql, qu, ex = 1,
-                                       xlab, ylab, percentages))
-    }
+                                                  percentages))
+      print(p1)
+      
+      if(returnPlot){
+        return(p1)
+      }
+      
+      
   }
 
 }
